@@ -20,3 +20,6 @@ bzr add $TARGETDIR/icons/*
 
 ../main/util/addPopconData.py -d ./menu-data
 ../main/util/addPopconData.py -d ./menu-data-additional
+../main/util/addPopconData.py -d ./menu-data-firefox
+../main/util/addPopconData.py -d ./menu-data-codecs
+
